@@ -12,9 +12,10 @@ from clairmeta.utils.file import human_size
 from clairmeta.utils.sys import keys_by_name_dict, keys_by_pattern_dict
 from clairmeta.utils.xml import parse_xml
 from clairmeta.utils.probe import unwrap_mxf
-from clairmeta.dcp_check import CheckerBase, CheckException
+from clairmeta.dcp_check import CheckerBase
 from clairmeta.dcp_check_utils import check_xml
 from clairmeta.dcp_utils import (list_cpl_assets, get_reel_for_asset,
+                                 get_first_reel_for_asset_type,
                                  get_contentkey_for_asset)
 from clairmeta.settings import DCP_SETTINGS
 from clairmeta.logger import get_log
@@ -33,7 +34,7 @@ class SubtitleUtils(object):
         else:
             xml_path = os.path.join(folder, os.path.splitext(asset['Path'])[0])
 
-        if not os.path.exists(xml_path):
+        if not os.path.isfile(xml_path):
             return
 
         return parse_xml(
@@ -66,9 +67,7 @@ class SubtitleUtils(object):
         tick = int(tick)
         time_base = 1.0 / edit_rate
 
-        # Ceiling division. Ugly, but avoids importing math.ceil
-        # https://stackoverflow.com/questions/14822184/is-there-a-ceiling-equivalent-of-operator-in-python#17511341
-        return int(-(-(tick * 0.004) // time_base))
+        return int((tick * 0.004) // time_base)
 
     def st_tc_frames(self, tc, edit_rate):
         """ Convert TimeCode to frame count.
@@ -167,9 +166,9 @@ class SubtitleUtils(object):
 
 class Checker(CheckerBase):
 
-    def __init__(self, dcp, profile):
+    def __init__(self, dcp):
         self.st_util = SubtitleUtils(dcp)
-        super(Checker, self).__init__(dcp, profile)
+        super(Checker, self).__init__(dcp)
 
     def run_checks(self):
         for cpl in self.dcp._list_cpl:
@@ -218,12 +217,16 @@ class Checker(CheckerBase):
     def check_subtitle_dcp_format(self, playlist, asset):
         """ Subtitle format (related to DCP Standard) check.
 
-            Reference :
-                SMPTE ST 429-5
-                Interop Closed Captions Packaging 1.9
+            References:
+                Closed Captions Packaging (v1.9)
+                https://interop-docs.cinepedia.com/Addition_To_Document_Release_2.0/ClosedCaption_Interop_2007_11_16_v1_9(clean).pdf
+                SMPTE ST 429-5:2017
         """
         _, asset = asset
         asset_path = asset['Path']
+        if not asset_path:
+            return
+
         extension_by_schema = {
             'Interop': '.xml',
             'SMPTE': '.mxf'
@@ -231,18 +234,20 @@ class Checker(CheckerBase):
         ext = os.path.splitext(asset['Path'])[-1].lower()
 
         if ext != extension_by_schema[self.dcp.schema]:
-            raise CheckException("Wrong subtitle format for asset {}".format(
-                asset_path))
+            self.error("Wrong subtitle format for asset {}".format(asset_path))
 
     def check_subtitle_cpl_xml(self, playlist, asset, folder):
         """ Subtitle XML file syntax and structure validation.
 
-            Reference :
-                SMPTE ST 428-7
-                Interop TI Subtitle Spec 1.1
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1)
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014
         """
         _, asset = asset
         asset_path = asset['Path']
+        if not asset_path:
+            return
 
         if asset_path.endswith('.xml'):
             path = os.path.join(self.dcp.path, asset_path)
@@ -254,18 +259,19 @@ class Checker(CheckerBase):
             label = asset['Probe']['LabelSetType']
 
         if not os.path.exists(path):
-            raise CheckException("Subtitle not found : {}".format(path))
+            self.error("Subtitle not found : {}".format(path))
         if not os.path.isfile(path):
-            raise CheckException("Subtitle must be a file : {}".format(path))
+            self.error("Subtitle must be a file : {}".format(path))
 
-        check_xml(path, namespace, label, self.dcp.schema)
+        check_xml(self, path, namespace, label, self.dcp.schema)
 
     def check_subtitle_cpl_reel_number(self, playlist, asset, folder):
         """ Subtitle reel number coherence with CPL.
 
-            Reference :
-                SMPTE 428-7-2014 5.6
-                Interop TI Subtitle Spec 1.1 2.5
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.5
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014 5.6
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -276,13 +282,13 @@ class Checker(CheckerBase):
         reel_cpl = get_reel_for_asset(playlist, asset['Id'])['Position']
 
         if reel_no and reel_no != reel_cpl:
-            raise CheckException("Subtitle file indicate Reel {} but actually "
-                                 "used in Reel {}".format(reel_no, reel_cpl))
+            self.error("Subtitle file indicate Reel {} but actually "
+                       "used in Reel {}".format(reel_no, reel_cpl))
 
     def check_subtitle_cpl_language(self, playlist, asset, folder):
         """ Subtitle language coherence with CPL.
 
-            Reference : N/A
+            References: N/A
         """
         def lookup_language(lang):
             """ Detect language from `lang` name. """
@@ -303,8 +309,8 @@ class Checker(CheckerBase):
         try:
             st_lang_obj = lookup_language(st_lang)
         except LookupError:
-            raise CheckException("Subtitle language from XML could not "
-                                 "be detected : {}".format(st_lang))
+            self.error("Subtitle language from XML could not be detected : {}"
+                       .format(st_lang))
 
         cpl_lang = asset.get('Language')
         if not cpl_lang:
@@ -312,13 +318,13 @@ class Checker(CheckerBase):
 
         cpl_lang_obj = lookup_language(cpl_lang)
         if not cpl_lang_obj:
-            raise CheckException("Subtitle language from CPL could not "
-                                 "be detected : {}".format(cpl_lang))
+            self.error("Subtitle language from CPL could not be detected : {}"
+                       .format(cpl_lang))
 
         if st_lang_obj != cpl_lang_obj:
-            raise CheckException(
-                "Subtitle language mismatch, CPL claims {} but XML {}".format(
-                    cpl_lang_obj.name, st_lang_obj.name))
+            self.error(
+                "Subtitle language mismatch, CPL claims {} but XML {}"
+                .format(cpl_lang_obj.name, st_lang_obj.name))
 
     def check_subtitle_cpl_loadfont(self, playlist, asset, folder):
         """ Text subtitle must contains one and only one LoadFont element.
@@ -329,35 +335,38 @@ class Checker(CheckerBase):
             not enforced at the XSD schema level so we explicitly check it
             here.
 
-            Reference :
-                SMPTE ST 428-7-2014 5.11.1
-                SMPTE ST 429-2-2013 8.4.1
+            On the other hand, Interop spec doesn't have strict requirement
+            on the presence of LoadFont tag.
 
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.7
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014 5.11.1
+                SMPTE ST 429-2:2013 8.4.1
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
             return
+        if self.dcp.schema == 'Interop':
+            return
 
-        if self.dcp.schema == 'SMPTE':
-            loadfont_attribute = "LoadFont@ID"
-        else:
-            loadfont_attribute = "LoadFont@Id"  # Interop
-
+        loadfont_attribute = "LoadFont@ID"
         text_elems = keys_by_name_dict(st_dict, 'Text')
         loadfont_elems = keys_by_name_dict(st_dict, loadfont_attribute)
         if text_elems and len(loadfont_elems) != 1:
-            raise CheckException(
+            self.error(
                 "Text based subtitle shall contain one and only one "
                 "LoadFont element, found {}".format(len(loadfont_elems)))
         if text_elems and not loadfont_elems[0]:
-            raise CheckException("LoadFont element with an empty ID attribute")
+            self.error("LoadFont element with an empty ID attribute")
 
     def check_subtitle_cpl_font_ref(self, playlist, asset, folder):
         """ Subtitle font references check.
 
-            Reference :
-                SMPTE ST 428-7-2014 5.11.1
-                Interop TI Subtitle Spec 1.1 2.7
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.7
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014 5.11.1
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -372,14 +381,13 @@ class Checker(CheckerBase):
 
         for ref in font_ref:
             if ref != font_id:
-                raise CheckException(
-                    "Subtitle reference unknown font {} (loaded {})".format(
-                        ref, font_id))
+                self.error("Subtitle reference unknown font {} (loaded {})"
+                           .format(ref, font_id))
 
     def check_subtitle_cpl_font(self, playlist, asset, folder):
         """ Subtitle font file exists.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -389,13 +397,14 @@ class Checker(CheckerBase):
             return
 
         if not os.path.exists(path):
-            raise CheckException("Subtitle missing font file : {}".format(uri))
+            self.error("Subtitle missing font file : {}".format(uri))
 
     def check_subtitle_cpl_font_size(self, playlist, asset, folder):
         """ Subtitle maximum font size.
 
-            Reference :
-                Interop TI Subtitle Spec 1.1 2.7
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.7
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -410,14 +419,14 @@ class Checker(CheckerBase):
         font_max_size = DCP_SETTINGS['subtitle']['font_max_size']
 
         if font_size > font_max_size:
-            raise CheckException(
+            self.error(
                 "Subtitle font maximum size is {}, got {}".format(
                     human_size(font_max_size), human_size(font_size)))
 
     def check_subtitle_cpl_font_glyph(self, playlist, asset, folder):
         """ Check for missing font glyphs.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -452,7 +461,7 @@ class Checker(CheckerBase):
                 missing_glyphs.append(char)
 
         if missing_glyphs:
-            raise CheckException(
+            self.error(
                 "Font ({}) is missing required glyphs : {}"
                 .format(os.path.basename(path), ", ".join(missing_glyphs)))
 
@@ -460,7 +469,7 @@ class Checker(CheckerBase):
     def check_subtitle_cpl_st_timing(self, playlist, asset, folder):
         """ Subtitle individual duration / fade time check.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -479,23 +488,90 @@ class Checker(CheckerBase):
                 - self.st_util.st_tc_frames(st_in, editrate))
 
             if dur <= 0:
-                raise CheckException(
+                self.error(
                     "Subtitle {} null or negative duration".format(st_idx))
 
             f_s, f_d = self.st_util.get_subtitle_fade_io(st, editrate)
             if f_s and f_s > dur:
-                raise CheckException(
-                    "Subtitle {} FadeUpTime longer than duration".format(
-                        st_idx))
+                self.error("Subtitle {} FadeUpTime longer than duration"
+                           .format(st_idx))
             if f_d and f_d > dur:
-                raise CheckException(
-                    "Subtitle {} FadeDownTime longer than duration".format(
-                        st_idx))
+                self.error("Subtitle {} FadeDownTime longer than duration"
+                           .format(st_idx))
+
+    def check_subtitle_cpl_concurrent_visibility(self, playlist, asset, folder):
+        """ Maximum number of subtitle visible on screen at once.
+
+            Up to two (2) subtitle instances may be visible on screen
+            at any time. The visibility period of an instance shall include
+            fade-in and fade-out times.
+
+            Reference :
+                SMPTE 429-2-2013 8.4.4
+        """
+        st_dict = self.st_util.get_subtitle_xml(asset, folder)
+        if not st_dict:
+            return
+
+        subtitles = keys_by_name_dict(st_dict, 'Subtitle')
+        editrate = self.st_util.get_subtitle_editrate(asset, st_dict)
+        if not subtitles:
+            return
+
+        st_list = []
+        for idx, st in enumerate(subtitles[0]):
+            st_in, st_out = st['Subtitle@TimeIn'], st['Subtitle@TimeOut']
+            st_list.append((idx, self.st_util.st_tc_frames(st_in, editrate), 0))
+            st_list.append((idx, self.st_util.st_tc_frames(st_out, editrate), 1))
+        st_list = sorted(st_list, key=lambda x: (x[1], x[0], x[2]))
+
+        vis_list = []
+        current_vis = 0
+        for idx, st in enumerate(st_list):
+            current_vis += 1 if st[2] == 0 else -1
+            vis_list.append(current_vis)
+
+        for idx, v in enumerate(vis_list):
+            if v > 2:
+                st = subtitles[0][st_list[idx][0]]
+                st_in, st_out = st['Subtitle@TimeIn'], st['Subtitle@TimeOut']
+                self.error(
+                    "Too many subtitles ({}) visible at once between {} and {}"
+                    .format(v, st_in, st_out))
+
+    def check_subtitle_cpl_max_elements(self, playlist, asset, folder):
+        """ Maximum number of subtitle Text or Image elements.
+
+            A subtitle instance shall contain no more than six (6) Text
+            elements or three (3) Image elements.
+
+            Reference :
+                SMPTE 429-2-2013 8.4.4
+        """
+        st_dict = self.st_util.get_subtitle_xml(asset, folder)
+        if not st_dict:
+            return
+
+        subtitles = keys_by_name_dict(st_dict, 'Subtitle')
+        if not subtitles:
+            return
+
+        for idx, st in enumerate(subtitles[0]):
+            text_count = len(keys_by_name_dict(st, 'Text'))
+            if text_count > 6:
+                self.error(
+                    "Too many Text elements ({}) for subtitle {}"
+                    .format(text_count, st['Subtitle@SpotNumber']))
+            img_count = len(keys_by_name_dict(st, 'Image'))
+            if img_count > 6:
+                self.error(
+                    "Too many Image elements ({}) for subtitle {}"
+                    .format(img_count, st['Subtitle@SpotNumber']))
 
     def check_subtitle_cpl_duration(self, playlist, asset, folder):
         """ Subtitle duration coherence with CPL.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -520,7 +596,7 @@ class Checker(CheckerBase):
 
         if last_tc_st > cpl_dur:
             reel_cpl = get_reel_for_asset(playlist, asset['Id'])['Position']
-            raise CheckException(
+            self.error(
                 "Subtitle exceed track duration. Subtitle {} - Track {} "
                 "- Reel {}".format(
                     frame_to_tc(last_tc_st, cpl_rate),
@@ -530,7 +606,7 @@ class Checker(CheckerBase):
     def check_subtitle_cpl_editrate(self, playlist, asset, folder):
         """ Subtitle editrate coherence with CPL.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -542,10 +618,28 @@ class Checker(CheckerBase):
 
         if self.dcp.schema == 'SMPTE':
             if st_rate != cpl_rate:
-                raise CheckException(
+                self.error(
                     "Subtitle EditRate mismatch, Subtitle claims {} but CPL "
                     "{}".format(st_rate, cpl_rate))
 
+    def check_subtitle_cpl_entry_point(self, playlist, asset, folder):
+        """ Subtitle EntryPoint must be 0.
+
+            For all MainSubtitle or ClosedCaption timed text tracks, the
+            Composition Playlist’s EntryPoint element as defined in
+            SMPTE ST 429-7 shall be present and have a value of "0".
+
+            Reference :
+                SMPTE RDD 52:2020 8.3.2
+        """
+        _, asset = asset
+        cpl_entry = asset['EntryPoint']
+
+        if cpl_entry != 0:
+            self.error(
+                "Timed Text EntryPoint must be 0 but found {}".format(
+                    cpl_entry))
+
     def check_subtitle_cpl_uuid(self, playlist, asset, folder):
         """ Subtitle UUID coherence.
 
@@ -556,8 +650,9 @@ class Checker(CheckerBase):
             (As_02_TimedText parser) store the TimedTextDescriptor/ResourceID
             in a global AssetID key.
 
-            Reference :
-                SMPTE 429-5-2017
+            References:
+                SMPTE ST 429-5:2017
+                SMPTE RDD 52:2020 10.4
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -569,18 +664,18 @@ class Checker(CheckerBase):
         if self.dcp.schema == 'Interop':
             cpl_uuid = asset['Id'].lower()
             if st_uuid != cpl_uuid:
-                raise CheckException(
+                self.error(
                     "Subtitle UUID mismatch, Subtitle claims {} but CPL {}"
                     .format(st_uuid, cpl_uuid))
             folder_name = os.path.basename(folder).lower()
             if st_uuid not in folder_name:
-                raise CheckException(
+                self.error(
                     "Subtitle directory name unexpected, should contain {} but"
                     " got {}".format(st_uuid, folder_name))
         elif self.dcp.schema == 'SMPTE':
             resource_uuid = asset['Probe'].get('AssetID', "").lower()
             if resource_uuid != st_uuid:
-                raise CheckException(
+                self.error(
                     "Subtitle UUID mismatch, Subtitle claims {} but MXF "
                     "{}".format(st_uuid, resource_uuid))
 
@@ -596,13 +691,13 @@ class Checker(CheckerBase):
         if self.dcp.schema == 'Interop':
             cpl_uuid = asset['Id']
             if st_uuid != cpl_uuid and st_uuid.lower() == cpl_uuid.lower():
-                raise CheckException(
+                self.error(
                     "Subtitle UUID case mismatch, Subtitle {} - CPL {}".format(
                         st_uuid, cpl_uuid))
             folder_name = os.path.basename(folder)
             if (st_uuid not in folder_name
                and st_uuid.lower() in folder_name.lower()):
-                raise CheckException(
+                self.error(
                     "Subtitle directory name case mismatch, Folder {} - CPL {}"
                     .format(st_uuid, folder_name))
 
@@ -616,7 +711,7 @@ class Checker(CheckerBase):
             created using the same universally unique identifier (UUID) for
             the MXF file and the main XML inside the MXF files. [DCPLYR-3418]
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -628,14 +723,14 @@ class Checker(CheckerBase):
         if self.dcp.schema == 'SMPTE':
             mxf_uuid = asset['Probe'].get('AssetUUID', "")
             if st_uuid == mxf_uuid:
-                raise CheckException(
+                self.error(
                     "Using the same UUID for Subtitle ID and MXF UUID can "
                     "cause issue on Dolby server prior to 2.8.18 firmware.")
 
     def check_subtitle_cpl_empty(self, playlist, asset, folder):
         """ Empty Subtitle file check.
 
-            Reference : N/A
+            References: N/A
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -643,14 +738,15 @@ class Checker(CheckerBase):
 
         subtitles = keys_by_name_dict(st_dict, 'Subtitle')
         if not subtitles:
-            raise CheckException("Subtitle file is empty")
+            self.error("Subtitle file is empty")
 
     def check_subtitle_cpl_content(self, playlist, asset, folder):
         """ Subtitle individual structure check.
 
-            Reference :
-                Interop TI Subtitle Spec 1.1 2.9
-                SMPTE 428-7-2014 6
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.9
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014 6
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -664,9 +760,8 @@ class Checker(CheckerBase):
             has_image = keys_by_name_dict(st, 'Image')
             has_text = keys_by_name_dict(st, 'Text')
             if not has_image and not has_text:
-                raise CheckException(
-                    "Subtitle {} element must define one Text or Image"
-                    "".format(st['Subtitle@SpotNumber']))
+                self.error("Subtitle {} element must define one Text or Image"
+                           .format(st['Subtitle@SpotNumber']))
 
     def check_subtitle_cpl_position(self, playlist, asset, folder):
         """ Subtitles vertical position (out of screen) check.
@@ -674,9 +769,10 @@ class Checker(CheckerBase):
             VAlign="top", VPosition="0" : out of the top of the screen
             VAlign="bottom", VPosition="0" : some char like 'g' will be cut
 
-            Reference :
-                Interop TI Subtitle Spec 1.1 2.10
-                SMPTE 428-7-2014 6.2.4
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.10
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
+                SMPTE ST 428-7:2014 6.2.4
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -692,18 +788,19 @@ class Checker(CheckerBase):
 
             for a, p in zip(valign, vpos):
                 if a == 'top' and p == 0:
-                    raise CheckException(
+                    self.error(
                         "Subtitle {} is out of screen (top)".format(st_idx))
                 if a == 'bottom' and p == 0:
-                    raise CheckException(
+                    self.error(
                         "Subtitle {} is nearly out of screen (bottom), some "
                         "characters will be cut".format(st_idx))
 
     def check_subtitle_cpl_image(self, playlist, asset, folder):
         """ Subtitle image element must reference a valid PNG file.
 
-            Reference :
-                Interop TI Subtitle Spec 1.1 2.17
+            References:
+                TI Subtitle Specification for DLP Cinema (v1.1) 2.17
+                https://web.archive.org/web/20140924175755/http://dlp.com/downloads/pdf_dlp_cinema_CineCanvas_Rev_C.pdf
         """
         st_dict = self.st_util.get_subtitle_xml(asset, folder)
         if not st_dict:
@@ -715,6 +812,40 @@ class Checker(CheckerBase):
         imgs = keys_by_name_dict(st_dict, 'Image')
         for img in imgs:
             if not os.path.exists(os.path.join(folder, img)):
-                raise CheckException(
+                self.error(
                     "Subtitle image reference {} not found in folder {}"
                     "".format(img, os.path.relpath(folder, self.dcp.path)))
+
+    def check_subtitle_cpl_first_tt_event(self, playlist, asset, folder):
+        """ First Timed Text Event of Composition TimeIn greater than 4s.
+
+            The composition's first Timed Text event's TimeIn attribute
+            should be greater than or equal to 4 seconds.
+
+            Reference:
+                SMPTE RDD 52:2020 7.2.4
+        """
+        reel_cpl = get_reel_for_asset(playlist, asset[1]['Id'])['Position']
+        first_reel_of_st = get_first_reel_for_asset_type(playlist, 'Subtitle')
+        # We are probably checking a Caption track
+        if not first_reel_of_st:
+            return None
+        first_reel_of_st = first_reel_of_st['Position']
+        if not first_reel_of_st or reel_cpl != first_reel_of_st:
+            return
+
+        st_dict = self.st_util.get_subtitle_xml(asset, folder)
+        if not st_dict:
+            return
+
+        subtitles = keys_by_name_dict(st_dict, 'Subtitle')
+        if not subtitles:
+            return
+
+        st_editrate = self.st_util.get_subtitle_editrate(asset, st_dict)
+        first_tc = subtitles[0][0]['Subtitle@TimeIn']
+        first_tc_frames = self.st_util.st_tc_frames(first_tc, st_editrate)
+
+        if (first_tc_frames < 4 * st_editrate):
+            self.error("First Timed Text event of CPL happens "
+                       "earlier than 4 seconds: {}".format(first_tc))
